#[repr(u8)]pub enum NumberOfRinses {
None = 0,
Normal = 1,
Extra = 2,
Max = 3,
}Variants
None = 0
This laundry washer mode does not perform rinse cycles
Normal = 1
This laundry washer mode performs normal rinse cycles determined by the manufacturer
Extra = 2
This laundry washer mode performs an extra rinse cycle
Max = 3
This laundry washer mode performs the maximum number of rinse cycles determined by the manufacturer
Implementations